///https://www.shadertoy.com/view/NstSWf////
#version 120
precision highp float;

uniform vec3                iResolution;
uniform float               iTime;
uniform sampler2D           iChannel0;
varying vec2                texCoord;
uniform float               intensity;
uniform int mappedID;
void mainImage( out vec4 fragColor, in vec2 fragCoord ) {
    vec2 uv = fragCoord / iResolution.xy ; // x: [0, 5[ and y: [0, 3[
    // Base and overlay texture for blending. Sometime we only use base (t1)
    vec4 t1 = texture2D(iChannel0, uv);
    vec4 t2 = texture2D(iChannel1, uv);
    // Shadertoy's (non-noise) texture2Ds are in sRGB. Turn them into linear space for manipulation. Turn them back at the end
    t1 = pow(t1, vec4(2.2));
    t2 = pow(t2, vec4(2.2));
    // === Ok, start!
    vec4 color;
    switch (mappedID) {
        case 1: // blend: dissolve
        color = mix(t1, t2, intensity);
        break;
        case 2: // blend: lighten
        color = max(t1, t2);
        break;
        case 3: // blend: darken
        color = min(t1, t2);
        break;
        case 4: // blend: subtract
        color = t1 - t2;
        break;
        case 5: // blend: multiply. Would require more calculations for non-1 alpha
        color = t2 * t1;
        break;
        case 6: // blend: add. Would require more calculations for non-1 alpha
        color = t1 + t2;
        break;
        case 7: // blend: divide. Would require more calculations for non-1 alpha
        color = t1 / t2;
        break;
        case 8: // luminence
        vec3 weights = vec3(0.2125, 0.7154, 0.0721); // sums to 1
        float luminance = dot(t1.rgb, weights);
        color = vec4(vec3(luminance), 1.);
        break;
        case 9: // brightness
        color = t1 + intensity;
        break;
        case 10: // contrast
        color = (t1 - .5) * intensity * 2. + .5; // 0 to 2 contrast
        break;
        case 11: // exposure
        color = t1 * pow(2., intensity);
        break;
        case 12: // gamma
        color = pow(t1, vec4(intensity) * 2.2); // 0 to 2.2, by convention
        break;
        case 13: // saturation
        vec3 weights_ = vec3(0.2125, 0.7154, 0.0721); // sums to 1
        float luminance_ = dot(t1.rgb, weights_);
        color = mix(vec4(luminance_), t1, vec4(intensity) * 5.);
        break;
        case 14: // vibrance
        float average = (t1.r + t1.g + t1.b) / 3.;
        float mx = max(t1.r, max(t1.g, t1.b));
        float amount = (mx - average) * intensity * 3. * 5.;
        color = t1 - (mx - t1) * amount;
        break;
        case 15: // inversion
        color = 1. - t1;
        break;
    }

    fragColor = pow(color, vec4(1./2.2)); // gamma correct back
}
void main() {
    mainImage(gl_FragColor, texCoord * iResolution.xy);
}
