precision mediump float;

varying vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform sampler2D lookupTexture;
uniform lowp float intensity;

uniform sampler2D uStarTexture;

void main() {
	// 获取图像颜色
	vec4 color = texture2D(inputImageTexture, textureCoordinate);

	// 计算亮度（简单方法是取RGB分量的加权和）
	float brightness = dot(color.rgb, vec3(0.299, 0.587, 0.114));

	// 设置亮度阈值，控制星星显示和大小
	float threshold = 0.5; // 星星显示的亮度阈值
	float starSize = brightness * 2.0; // 星星大小与亮度成正比
	starSize = clamp(starSize, 0.5, 2.0); // 控制星星大小在合理范围内

	vec4 starColor = vec4(0.0);
	if (brightness > threshold) {
		// 获取星星纹理颜色
		vec2 starCoord = textureCoordinate * starSize; // 缩放星星纹理
		starColor = texture2D(uStarTexture, fract(starCoord));

		// 将星星的颜色和图像颜色混合
		starColor = vec4(starColor.rgb * intensity, starColor.a);
	}

	// 混合星星效果和原始图像
	gl_FragColor = color + starColor;
}
