precision highp float;
varying vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform sampler2D lookupTexture;
uniform lowp float intensity;
uniform lowp  float maxColorValue;   // lut每个分量的有多少种颜色最大取值
uniform lowp  float latticeCount;    // 每排晶格数量
uniform lowp  float width;           // lut图片宽度
uniform lowp  float height;          // lut图片高度
void main(){
	highp vec4 textureColor = texture2D(inputImageTexture, textureCoordinate);
	if (textureColor.a == 0.0){
		gl_FragColor = textureColor;
	}else {
		// B通道对应LUT上的数值
		float blueColor = textureColor.b * maxColorValue;//.8f 204

		// 计算临近两个B通道所在的方形LUT单元格（从左到右从，上到下排列）
		highp vec2 quad_l, quad_h;
		quad_l.y = floor(floor(blueColor) / latticeCount);//12
		quad_l.x = floor(blueColor) - quad_l.y * latticeCount;//12
		quad_h.y = floor(ceil(blueColor) / latticeCount);//12
		quad_h.x = ceil(blueColor) - (quad_h.y * latticeCount);//12

		// 单位像素上的中心偏移量
		float px_length_x = 1.0 / width;
		float cell_length_x = 1.0 / latticeCount;
		float px_length_y = 1.0 / width;
		float cell_length_y = 1.0 / latticeCount;

		// 根据RG、B偏移量计算LUT上对应的(x,y)
		highp vec2  lut_pos_l, lut_pos_h;
		lut_pos_l.x = (quad_l.x * cell_length_x) + px_length_x / 2.0 + ((cell_length_x - px_length_x) * textureColor.r);
		lut_pos_l.y = (quad_l.y * cell_length_y) + px_length_y / 2.0 + ((cell_length_y - px_length_y) * textureColor.g);
		lut_pos_h.x = (quad_h.x * cell_length_x) + px_length_x / 2.0 + ((cell_length_x - px_length_x) * textureColor.r);
		lut_pos_h.y = (quad_h.y * cell_length_y) + px_length_y / 2.0 + ((cell_length_y - px_length_y) * textureColor.g);

		// 获取映射的LUT颜色
		lowp vec4  graded_color_l = texture2D(lookupTexture, lut_pos_l);
		lowp vec4  graded_color_h = texture2D(lookupTexture, lut_pos_h);
		lowp vec4  graded_color = mix(graded_color_l, graded_color_h, fract(blueColor));

		// 根据intensity定制效果程度
		vec4 newColor = mix(textureColor, graded_color, intensity);
		gl_FragColor = vec4(newColor.rgb,textureColor.a);
	}
}