precision highp float;

uniform vec3 iResolution; // 屏幕分辨率
uniform float iTime;      // 时间
uniform sampler2D iChannel0; // 相机图像纹理

varying vec2 texCoord;

// 生成 Perlin 噪声
float noise(vec2 uv) {
	return fract(sin(dot(uv, vec2(12.9898, 78.233))) * 43758.5453);
}

// 使用 Perlin 噪声生成噪点
float generateNoise(vec2 uv, float time) {
	float x = uv.x * 10.0 + time * 0.1;
	float y = uv.y * 10.0 + time * 0.1;
	return noise(vec2(x, y));
}

void main() {
	// 获取纹理坐标
	vec2 uv = texCoord;

	// 从相机图像纹理中获取颜色值
	vec3 col = texture2D(iChannel0, uv).rgb;

	// 计算相机图像的亮度
	float luminance = dot(col, vec3(0.299, 0.587, 0.114));

	// 根据亮度调整噪点的强度和密度
	float intensity = smoothstep(0.1, 0.9, luminance) * 0.5;
	float density = smoothstep(0.1, 0.9, luminance) * 0.1;

	// 生成噪点并添加到图像中
	float noiseValue = generateNoise(uv, iTime);
	col += vec3(noiseValue * intensity);

	// 输出最终颜色
	gl_FragColor = vec4(col, 1.0);
}
